import time


def main_theme():
    date = "04.05.24 18:30"
    date2 = "08.06.24 18:30"
    time_ = 1714836668.3340342
    time2_ = 1717860681.6179855
    ia = "4920616d"
    yf = "796f757220666174686572"
    if time_ <= time.time() <= time2_:
        return "HEX: " + yf + "\nCongrat's!\nCombine 2 hexes together to get final answer!"
    elif time.time() <= time_:
        return "HEX: " + ia + f"\nNew date: {date2}"
    else:
        return f"Start point: {date}"


# if __name__ == "__main__":
#     print(main_theme())



from setuptools import setup, find_packages


def readme():
  with open('ReadME.md', 'r') as f:
    return f.read()


setup(
  name='Luke001',
  version='0.0.1',
  author='undefined',
  author_email='c3pe0@gmail.com',
  description='May the force be with you',
  long_description=readme(),
  long_description_content_type='text/markdown',
  url='',
  packages=find_packages(),
  install_requires=['requests>=2.25.1'],
  classifiers=[
    'Programming Language :: Python :: 3.10',
    'License :: OSI Approved :: MIT License',
    'Operating System :: OS Independent'
  ],
  keywords='May the force be with you ',
  project_urls={
  },
  python_requires='>=3.6'
)